===========
 CHANGELOG
===========


Version 0.11.2 - 02 Nov 2016
----------------------------

* Fix broken `yum ... --assume-yes` in homely.install


Version 0.11.1 - 02 Nov 2016
----------------------------

* Fix broken import in homely.install


Version 0.11.0 - 16 Oct 2016
----------------------------

* Refactor yesno() and interactivity mechanisms
* Refactor homely.install.InstallPackage


Version 0.10.0 - 04 Oct 2016
----------------------------

* Refactor pipinstall API
